gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r19796 - in gnunet/src: ats include transport


From: gnunet
Subject: [GNUnet-SVN] r19796 - in gnunet/src: ats include transport
Date: Mon, 13 Feb 2012 18:00:10 +0100

Author: wachs
Date: 2012-02-13 18:00:10 +0100 (Mon, 13 Feb 2012)
New Revision: 19796

Modified:
   gnunet/src/ats/ats_api_scheduling.c
   gnunet/src/ats/gnunet-service-ats_addresses.c
   gnunet/src/ats/gnunet-service-ats_addresses_mlp.c
   gnunet/src/ats/gnunet-service-ats_addresses_mlp.h
   gnunet/src/include/gnunet_ats_service.h
   gnunet/src/transport/gnunet-service-transport.c
   gnunet/src/transport/gnunet-service-transport_neighbours.c
   gnunet/src/transport/transport_api_address_lookup.c
Log:
- doxygen errors


Modified: gnunet/src/ats/ats_api_scheduling.c
===================================================================
--- gnunet/src/ats/ats_api_scheduling.c 2012-02-13 16:36:32 UTC (rev 19795)
+++ gnunet/src/ats/ats_api_scheduling.c 2012-02-13 17:00:10 UTC (rev 19796)
@@ -754,6 +754,7 @@
 
 /**
  * Returns where the address is located: LAN or WAN or ...
+ * @param sh the scheduling handle
  * @param addr address
  * @param addrlen address length
  * @return location as GNUNET_ATS_Information

Modified: gnunet/src/ats/gnunet-service-ats_addresses.c
===================================================================
--- gnunet/src/ats/gnunet-service-ats_addresses.c       2012-02-13 16:36:32 UTC 
(rev 19795)
+++ gnunet/src/ats/gnunet-service-ats_addresses.c       2012-02-13 17:00:10 UTC 
(rev 19796)
@@ -39,14 +39,14 @@
 
 enum ATS_Mode
 {
-  /**
+  /*
    * Assign each peer an equal amount of bandwidth (bw)
    *
    * bw_per_peer = bw_total / #active addresses
    */
   SIMPLE,
 
-  /**
+  /*
    * Use MLP solver to assign bandwidth
    */
   MLP

Modified: gnunet/src/ats/gnunet-service-ats_addresses_mlp.c
===================================================================
--- gnunet/src/ats/gnunet-service-ats_addresses_mlp.c   2012-02-13 16:36:32 UTC 
(rev 19795)
+++ gnunet/src/ats/gnunet-service-ats_addresses_mlp.c   2012-02-13 17:00:10 UTC 
(rev 19796)
@@ -151,7 +151,7 @@
  * Translate ATS properties to text
  * Just intended for debugging
  *
- * @param retcode return code
+ * @param ats_index the ATS index
  * @return string with result
  */
 const char *
@@ -195,7 +195,9 @@
 
 /**
  * Find a peer in the DLL
- * @param the peer to find
+ *
+ * @param mlp the mlp handle
+ * @param peer the peer to find
  * @return the peer struct
  */
 static struct ATS_Peer *
@@ -381,6 +383,7 @@
  * Adds the problem constraints for all addresses
  * Required for problem recreation after address deletion
  *
+ * @param mlp the mlp handle
  * @param addresses all addresses
  */
 
@@ -684,6 +687,7 @@
  * Create the MLP problem
  *
  * @param mlp the MLP handle
+ * @param addresses the hashmap containing all adresses
  * @return GNUNET_OK or GNUNET_SYSERR
  */
 static int
@@ -1022,6 +1026,7 @@
 /**
  * Init the MLP problem solving component
  *
+ * @param cfg the GNUNET_CONFIGURATION_Handle handle
  * @param stats the GNUNET_STATISTICS handle
  * @param max_duration maximum numbers of iterations for the LP/MLP Solver
  * @param max_iterations maximum time limit for the LP/MLP Solver
@@ -1393,13 +1398,13 @@
  * @param mlp the MLP Handle
  * @param peer the peer
  * @param kind the kind to change the preference
- * @param float the score
+ * @param score the score
  */
 void
 GAS_mlp_address_change_preference (struct GAS_MLP_Handle *mlp,
                                    const struct GNUNET_PeerIdentity *peer,
                                    enum GNUNET_ATS_PreferenceKind kind,
-                                   float score)
+                                   float )
 {
   GNUNET_STATISTICS_update (mlp->stats,"# LP address preference changes", 1, 
GNUNET_NO);
 

Modified: gnunet/src/ats/gnunet-service-ats_addresses_mlp.h
===================================================================
--- gnunet/src/ats/gnunet-service-ats_addresses_mlp.h   2012-02-13 16:36:32 UTC 
(rev 19795)
+++ gnunet/src/ats/gnunet-service-ats_addresses_mlp.h   2012-02-13 17:00:10 UTC 
(rev 19796)
@@ -339,7 +339,7 @@
  * @param mlp the MLP Handle
  * @param peer the peer
  * @param kind the kind to change the preference
- * @param float the score
+ * @param score the score
  */
 void
 GAS_mlp_address_change_preference (struct GAS_MLP_Handle *mlp,

Modified: gnunet/src/include/gnunet_ats_service.h
===================================================================
--- gnunet/src/include/gnunet_ats_service.h     2012-02-13 16:36:32 UTC (rev 
19795)
+++ gnunet/src/include/gnunet_ats_service.h     2012-02-13 17:00:10 UTC (rev 
19796)
@@ -538,6 +538,7 @@
 
 /**
  * Returns where the address is located: LAN or WAN or ...
+ * @param sh the GNUNET_ATS_SchedulingHandle handle
  * @param addr address
  * @param addrlen address length
  * @return location as GNUNET_ATS_Information

Modified: gnunet/src/transport/gnunet-service-transport.c
===================================================================
--- gnunet/src/transport/gnunet-service-transport.c     2012-02-13 16:36:32 UTC 
(rev 19795)
+++ gnunet/src/transport/gnunet-service-transport.c     2012-02-13 17:00:10 UTC 
(rev 19796)
@@ -120,7 +120,7 @@
  * @param peer (claimed) identity of the other peer
  * @param address the address
  * @param session session used
- * @param msg the message to process
+ * @param message the message to process
  * @param ats performance information
  * @param ats_count number of records in ats
  * @return how long the plugin should wait until receiving more data
@@ -408,7 +408,7 @@
  * @param bandwidth_out assigned outbound bandwidth for the connection, 0 to 
disconnect from peer
  * @param bandwidth_in assigned inbound bandwidth for the connection, 0 to 
disconnect from peer
  * @param ats ATS information
- * @param number of ATS elements
+ * @param ats_count number of ATS elements
  */
 static void
 ats_request_address_change (void *cls,

Modified: gnunet/src/transport/gnunet-service-transport_neighbours.c
===================================================================
--- gnunet/src/transport/gnunet-service-transport_neighbours.c  2012-02-13 
16:36:32 UTC (rev 19795)
+++ gnunet/src/transport/gnunet-service-transport_neighbours.c  2012-02-13 
17:00:10 UTC (rev 19796)
@@ -791,19 +791,19 @@
  * @param cls closure for callbacks
  * @param connect_cb function to call if we connect to a peer
  * @param disconnect_cb function to call if we disconnect from a peer
  * @param address_cb function to call if we change an active address
  *                   of a neighbour
  */
 void
 GST_neighbours_start (void *cls,
                       GNUNET_TRANSPORT_NotifyConnect connect_cb,
                       GNUNET_TRANSPORT_NotifyDisconnect disconnect_cb,
-                      GNUNET_TRANSPORT_PeerIterateCallback address_cb)
+                      GNUNET_TRANSPORT_PeerIterateCallback peer_address_cb)
 {
   callback_cls = cls;
   connect_notify_cb = connect_cb;
   disconnect_notify_cb = disconnect_cb;
-  address_change_cb = address_cb;
+  address_change_cb = peer_address_cb;
   neighbours = GNUNET_CONTAINER_multihashmap_create (NEIGHBOUR_TABLE_SIZE);
 }
 

Modified: gnunet/src/transport/transport_api_address_lookup.c
===================================================================
--- gnunet/src/transport/transport_api_address_lookup.c 2012-02-13 16:36:32 UTC 
(rev 19795)
+++ gnunet/src/transport/transport_api_address_lookup.c 2012-02-13 17:00:10 UTC 
(rev 19796)
@@ -19,7 +19,7 @@
 */
 
 /**
- * @file transport/transport_api_peer_address_lookup.c
+ * @file transport/transport_api_address_lookup.c
  * @brief given a peer id, get all known addresses from transport service
  *
  * This api provides the ability to query the transport service about
@@ -791,19 +791,19 @@
  * @param connect_cb function to call if we connect to a peer
  * @param disconnect_cb function to call if we disconnect from a peer
- * @param address_cb function to call if we change an active address
+ * @param peer_address_cb function to call if we change an active address
  *                   of a neighbour
  */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]